# coding: utf-8

"""
    Operation Registry API

    Register operations with the Operation Registry API.

    OpenAPI spec version: 0.1.9
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into model package
from .credentials import Credentials
from .error import Error
from .operation_version import OperationVersion
from .operation_version_patch import OperationVersionPatch
from .operation_version_post import OperationVersionPost
from .operations import Operations
from .operations_patch import OperationsPatch
from .operations_post import OperationsPost
from .token_resp import TokenResp
from .user import User



from django.contrib.auth.models import User
from django.http import HttpResponse
from django.template import Template, Context
from django.template.loader import get_template, TemplateDoesNotExist

from common_dibbs.config.configuration import Configuration


class ClientAuthenticationBackend(object):
    def authenticate(self, username=None, password=None, session_key=None):
        from common_dibbs.clients.cas_client.apis.authentication_api import AuthenticationApi

        # Create a client for Authentication
        operations_client = AuthenticationApi()
        operations_client.api_client.host = "%s" % (Configuration().get_central_authentication_service_url(),)

        result = operations_client.authenticate_post(**{
            "username": username,
            "password": password,
            "session_key": session_key,
        })

        user = None
        if result.response:
            user = User()
            user.username = result.username

        return {
            "user": user,
            "token": result.token
        }

default_redirect_form_value = """<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Redirection to authentication server</title>
</head>
<body>
    <form id="redirect_form" action="{{ cas_service_target_url }}" method="POST">
        <input type="hidden" name="session_key" value="{{ session_key }}">
        <input type="hidden" name="redirect_url" value="{{ redirect_url }}">
        <button type="submit">You will be redirected to the authentication server</button>
    </form>
</body>
</html>
"""

class CentralAuthenticationMiddleware(object):
    def process_request(self, request):
        username = request.META.get('X_USERNAME')
        password = request.META.get('X_PASSWORD')
        session_key = request.session.session_key

        auth_backend = ClientAuthenticationBackend()

        # Check if the current session has already been authenticated by the CAS: authentication is successful
        authentication_resp = auth_backend.authenticate(username, password, session_key)

        if authentication_resp["user"] is not None and authentication_resp["user"].username not in ["", "anonymous"]:
            request.user = authentication_resp["user"]
            return

        # Do a web redirection to the CAS service
        redirect_url = "http://%s%s" % (request.META.get('HTTP_HOST'), request.path)
        cas_service_target_url = "%s" % (Configuration().get_central_authentication_service_url(), )

        data = {
            "request": request,
            "session_key": session_key,
            "redirect_url": redirect_url,
            "cas_service_target_url": cas_service_target_url
        }

        try:
            t = get_template("redirect_form.html")
        except TemplateDoesNotExist:
            t = Template(default_redirect_form_value)

        c = Context(data)
        html_source = str(t.render(c))

        # Redirection via a form
        return HttpResponse(html_source)

LOGGED_USERS = {

}



# coding: utf-8

"""
    Operation Manager API

    Execute operations with the Operation Manager API.

    OpenAPI spec version: 0.1.4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Execution(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, author=None, operation_instance=None, callback_url=None, force_spawn_cluster=None, creation_date=None, status=None, status_info=None, resource_provisioner_token=None, output_location=None):
        """
        Execution - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'author': 'int',
            'operation_instance': 'int',
            'callback_url': 'str',
            'force_spawn_cluster': 'str',
            'creation_date': 'datetime',
            'status': 'str',
            'status_info': 'str',
            'resource_provisioner_token': 'str',
            'output_location': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'author': 'author',
            'operation_instance': 'operation_instance',
            'callback_url': 'callback_url',
            'force_spawn_cluster': 'force_spawn_cluster',
            'creation_date': 'creation_date',
            'status': 'status',
            'status_info': 'status_info',
            'resource_provisioner_token': 'resource_provisioner_token',
            'output_location': 'output_location'
        }

        self._id = id
        self._author = author
        self._operation_instance = operation_instance
        self._callback_url = callback_url
        self._force_spawn_cluster = force_spawn_cluster
        self._creation_date = creation_date
        self._status = status
        self._status_info = status_info
        self._resource_provisioner_token = resource_provisioner_token
        self._output_location = output_location

    @property
    def id(self):
        """
        Gets the id of this Execution.
        Unique identifier representing a specific execution

        :return: The id of this Execution.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Execution.
        Unique identifier representing a specific execution

        :param id: The id of this Execution.
        :type: int
        """

        self._id = id

    @property
    def author(self):
        """
        Gets the author of this Execution.
        Unique ID of the user who created the execution

        :return: The author of this Execution.
        :rtype: int
        """
        return self._author

    @author.setter
    def author(self, author):
        """
        Sets the author of this Execution.
        Unique ID of the user who created the execution

        :param author: The author of this Execution.
        :type: int
        """

        self._author = author

    @property
    def operation_instance(self):
        """
        Gets the operation_instance of this Execution.
        Unique ID of the process instance this execution is of

        :return: The operation_instance of this Execution.
        :rtype: int
        """
        return self._operation_instance

    @operation_instance.setter
    def operation_instance(self, operation_instance):
        """
        Sets the operation_instance of this Execution.
        Unique ID of the process instance this execution is of

        :param operation_instance: The operation_instance of this Execution.
        :type: int
        """

        self._operation_instance = operation_instance

    @property
    def callback_url(self):
        """
        Gets the callback_url of this Execution.
        URL called after completion of the job (possibly empty)

        :return: The callback_url of this Execution.
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """
        Sets the callback_url of this Execution.
        URL called after completion of the job (possibly empty)

        :param callback_url: The callback_url of this Execution.
        :type: str
        """

        self._callback_url = callback_url

    @property
    def force_spawn_cluster(self):
        """
        Gets the force_spawn_cluster of this Execution.
        If set and not empty, forces the creation of a new cluster

        :return: The force_spawn_cluster of this Execution.
        :rtype: str
        """
        return self._force_spawn_cluster

    @force_spawn_cluster.setter
    def force_spawn_cluster(self, force_spawn_cluster):
        """
        Sets the force_spawn_cluster of this Execution.
        If set and not empty, forces the creation of a new cluster

        :param force_spawn_cluster: The force_spawn_cluster of this Execution.
        :type: str
        """

        self._force_spawn_cluster = force_spawn_cluster

    @property
    def creation_date(self):
        """
        Gets the creation_date of this Execution.
        Date and time of creation of the execution

        :return: The creation_date of this Execution.
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this Execution.
        Date and time of creation of the execution

        :param creation_date: The creation_date of this Execution.
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def status(self):
        """
        Gets the status of this Execution.
        Status of the cluster

        :return: The status of this Execution.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Execution.
        Status of the cluster

        :param status: The status of this Execution.
        :type: str
        """

        self._status = status

    @property
    def status_info(self):
        """
        Gets the status_info of this Execution.
        More information about the status of the cluster

        :return: The status_info of this Execution.
        :rtype: str
        """
        return self._status_info

    @status_info.setter
    def status_info(self, status_info):
        """
        Sets the status_info of this Execution.
        More information about the status of the cluster

        :param status_info: The status_info of this Execution.
        :type: str
        """

        self._status_info = status_info

    @property
    def resource_provisioner_token(self):
        """
        Gets the resource_provisioner_token of this Execution.
        Authentication token to be used to connect to the Resource Provisioner

        :return: The resource_provisioner_token of this Execution.
        :rtype: str
        """
        return self._resource_provisioner_token

    @resource_provisioner_token.setter
    def resource_provisioner_token(self, resource_provisioner_token):
        """
        Sets the resource_provisioner_token of this Execution.
        Authentication token to be used to connect to the Resource Provisioner

        :param resource_provisioner_token: The resource_provisioner_token of this Execution.
        :type: str
        """

        self._resource_provisioner_token = resource_provisioner_token

    @property
    def output_location(self):
        """
        Gets the output_location of this Execution.
        Location of the output file of the job on the machine, empty if not yet completed

        :return: The output_location of this Execution.
        :rtype: str
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this Execution.
        Location of the output file of the job on the machine, empty if not yet completed

        :param output_location: The output_location of this Execution.
        :type: str
        """

        self._output_location = output_location

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Appliance Registry API

    Store appliances with the Appliance Registry API.

    OpenAPI spec version: 0.1.13
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class SitesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def sites_get(self, **kwargs):
        """
        Get the list of all the sites registered.
        Get the list of all the sites registered. No authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_get(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[Site]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_get_with_http_info(**kwargs)
        else:
            (data) = self.sites_get_with_http_info(**kwargs)
            return data

    def sites_get_with_http_info(self, **kwargs):
        """
        Get the list of all the sites registered.
        Get the list of all the sites registered. No authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_get_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: list[Site]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_get" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/sites/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Site]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def sites_name_delete(self, name, **kwargs):
        """
        Delete an already existing site.
        Delete an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_delete(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_name_delete_with_http_info(name, **kwargs)
        else:
            (data) = self.sites_name_delete_with_http_info(name, **kwargs)
            return data

    def sites_name_delete_with_http_info(self, name, **kwargs):
        """
        Delete an already existing site.
        Delete an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_delete_with_http_info(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_name_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `sites_name_delete`")

        resource_path = '/sites/{name}/'.replace('{format}', 'json')
        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def sites_name_get(self, name, **kwargs):
        """
        Get a single site.
        Get a single site. Authentification is not required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_get(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_name_get_with_http_info(name, **kwargs)
        else:
            (data) = self.sites_name_get_with_http_info(name, **kwargs)
            return data

    def sites_name_get_with_http_info(self, name, **kwargs):
        """
        Get a single site.
        Get a single site. Authentification is not required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_get_with_http_info(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_name_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `sites_name_get`")

        resource_path = '/sites/{name}/'.replace('{format}', 'json')
        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Site',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def sites_name_patch(self, name, data, **kwargs):
        """
        Modify an already existing site.
        Modify an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_patch(name, data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :param SitePatch data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_name_patch_with_http_info(name, data, **kwargs)
        else:
            (data) = self.sites_name_patch_with_http_info(name, data, **kwargs)
            return data

    def sites_name_patch_with_http_info(self, name, data, **kwargs):
        """
        Modify an already existing site.
        Modify an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_patch_with_http_info(name, data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :param SitePatch data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_name_patch" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `sites_name_patch`")
        # verify the required parameter 'data' is set
        if ('data' not in params) or (params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `sites_name_patch`")

        resource_path = '/sites/{name}/'.replace('{format}', 'json')
        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Site',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def sites_name_put(self, name, data, **kwargs):
        """
        Redefine an already existing site.
        Redefine an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_put(name, data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :param SitePost data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_name_put_with_http_info(name, data, **kwargs)
        else:
            (data) = self.sites_name_put_with_http_info(name, data, **kwargs)
            return data

    def sites_name_put_with_http_info(self, name, data, **kwargs):
        """
        Redefine an already existing site.
        Redefine an already existing site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_name_put_with_http_info(name, data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: Name of the site (required)
        :param SitePost data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_name_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `sites_name_put`")
        # verify the required parameter 'data' is set
        if ('data' not in params) or (params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `sites_name_put`")

        resource_path = '/sites/{name}/'.replace('{format}', 'json')
        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Site',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def sites_post(self, data, **kwargs):
        """
        Add a new site.
        Add a new site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_post(data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SitePost data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.sites_post_with_http_info(data, **kwargs)
        else:
            (data) = self.sites_post_with_http_info(data, **kwargs)
            return data

    def sites_post_with_http_info(self, data, **kwargs):
        """
        Add a new site.
        Add a new site. Authentification is required. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.sites_post_with_http_info(data, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SitePost data: Site (required)
        :return: Site
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sites_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data' is set
        if ('data' not in params) or (params['data'] is None):
            raise ValueError("Missing the required parameter `data` when calling `sites_post`")

        resource_path = '/sites/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['api_key', 'basic']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Site',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))





class Configuration(object):

    def __init__(self):
        pass

    def get_appliance_registry_url(self):
        return "http://127.0.0.1:8003"

    def get_operation_registry_url(self):
        return "http://127.0.0.1:8000"

    def get_operation_manager_url(self):
        return "http://127.0.0.1:8001"

    def get_resource_manager_url(self):
        return "http://127.0.0.1:8002"

    def get_operation_manager_agent_url(self):
        return "http://127.0.0.1:8011"

    def get_resource_manager_agent_url(self):
        return "http://127.0.0.1:8012"

    def get_central_authentication_service_url(self):
        return "http://127.0.0.1:7000"



# coding: utf-8

"""
    Operation Registry API

    Register operations with the Operation Registry API.

    OpenAPI spec version: 0.1.9
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class OperationVersionPost(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, appliance=None, process_definition=None, cwd=None, script=None, output_type=None, output_parameters=None):
        """
        OperationVersionPost - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'appliance': 'str',
            'process_definition': 'int',
            'cwd': 'str',
            'script': 'str',
            'output_type': 'str',
            'output_parameters': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'appliance': 'appliance',
            'process_definition': 'process_definition',
            'cwd': 'cwd',
            'script': 'script',
            'output_type': 'output_type',
            'output_parameters': 'output_parameters'
        }

        self._name = name
        self._appliance = appliance
        self._process_definition = process_definition
        self._cwd = cwd
        self._script = script
        self._output_type = output_type
        self._output_parameters = output_parameters

    @property
    def name(self):
        """
        Gets the name of this OperationVersionPost.
        Name given to the process implementation

        :return: The name of this OperationVersionPost.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperationVersionPost.
        Name given to the process implementation

        :param name: The name of this OperationVersionPost.
        :type: str
        """

        self._name = name

    @property
    def appliance(self):
        """
        Gets the appliance of this OperationVersionPost.
        Name of the appliance on which the process implementation must be run

        :return: The appliance of this OperationVersionPost.
        :rtype: str
        """
        return self._appliance

    @appliance.setter
    def appliance(self, appliance):
        """
        Sets the appliance of this OperationVersionPost.
        Name of the appliance on which the process implementation must be run

        :param appliance: The appliance of this OperationVersionPost.
        :type: str
        """

        self._appliance = appliance

    @property
    def process_definition(self):
        """
        Gets the process_definition of this OperationVersionPost.
        Id of the process definition linked with this new implementation

        :return: The process_definition of this OperationVersionPost.
        :rtype: int
        """
        return self._process_definition

    @process_definition.setter
    def process_definition(self, process_definition):
        """
        Sets the process_definition of this OperationVersionPost.
        Id of the process definition linked with this new implementation

        :param process_definition: The process_definition of this OperationVersionPost.
        :type: int
        """

        self._process_definition = process_definition

    @property
    def cwd(self):
        """
        Gets the cwd of this OperationVersionPost.
        Working directory to be in when ruing the process implementation

        :return: The cwd of this OperationVersionPost.
        :rtype: str
        """
        return self._cwd

    @cwd.setter
    def cwd(self, cwd):
        """
        Sets the cwd of this OperationVersionPost.
        Working directory to be in when ruing the process implementation

        :param cwd: The cwd of this OperationVersionPost.
        :type: str
        """

        self._cwd = cwd

    @property
    def script(self):
        """
        Gets the script of this OperationVersionPost.
        Script to execute to run the process on the cluster

        :return: The script of this OperationVersionPost.
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this OperationVersionPost.
        Script to execute to run the process on the cluster

        :param script: The script of this OperationVersionPost.
        :type: str
        """

        self._script = script

    @property
    def output_type(self):
        """
        Gets the output_type of this OperationVersionPost.
        type of output (e.g. file, stream)

        :return: The output_type of this OperationVersionPost.
        :rtype: str
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        """
        Sets the output_type of this OperationVersionPost.
        type of output (e.g. file, stream)

        :param output_type: The output_type of this OperationVersionPost.
        :type: str
        """

        self._output_type = output_type

    @property
    def output_parameters(self):
        """
        Gets the output_parameters of this OperationVersionPost.
        JSON-formatted dictionary containing parameters regarding the output (depending on the output type)

        :return: The output_parameters of this OperationVersionPost.
        :rtype: str
        """
        return self._output_parameters

    @output_parameters.setter
    def output_parameters(self, output_parameters):
        """
        Sets the output_parameters of this OperationVersionPost.
        JSON-formatted dictionary containing parameters regarding the output (depending on the output type)

        :param output_parameters: The output_parameters of this OperationVersionPost.
        :type: str
        """

        self._output_parameters = output_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .operation_versions_api import OperationVersionsApi
from .operations_api import OperationsApi
from .users_api import UsersApi



# coding: utf-8

"""
    Operation Manager API

    Execute operations with the Operation Manager API.

    OpenAPI spec version: 0.1.4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class InstancePatch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, process_definition_id=None, parameters=None, files=None):
        """
        InstancePatch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'process_definition_id': 'int',
            'parameters': 'str',
            'files': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'process_definition_id': 'process_definition_id',
            'parameters': 'parameters',
            'files': 'files'
        }

        self._name = name
        self._process_definition_id = process_definition_id
        self._parameters = parameters
        self._files = files

    @property
    def name(self):
        """
        Gets the name of this InstancePatch.
        Name of the process instance, possibly empty

        :return: The name of this InstancePatch.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this InstancePatch.
        Name of the process instance, possibly empty

        :param name: The name of this InstancePatch.
        :type: str
        """

        self._name = name

    @property
    def process_definition_id(self):
        """
        Gets the process_definition_id of this InstancePatch.
        Unique ID of the operation on which an instance of the operation must be run

        :return: The process_definition_id of this InstancePatch.
        :rtype: int
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """
        Sets the process_definition_id of this InstancePatch.
        Unique ID of the operation on which an instance of the operation must be run

        :param process_definition_id: The process_definition_id of this InstancePatch.
        :type: int
        """

        self._process_definition_id = process_definition_id

    @property
    def parameters(self):
        """
        Gets the parameters of this InstancePatch.
        JSON-formatted string containing a dictionary mapping a value for each parameter declared in the process definition

        :return: The parameters of this InstancePatch.
        :rtype: str
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this InstancePatch.
        JSON-formatted string containing a dictionary mapping a value for each parameter declared in the process definition

        :param parameters: The parameters of this InstancePatch.
        :type: str
        """

        self._parameters = parameters

    @property
    def files(self):
        """
        Gets the files of this InstancePatch.
        JSON-formatted string containing a dictionary mapping each file declared in the process definition to a URL

        :return: The files of this InstancePatch.
        :rtype: str
        """
        return self._files

    @files.setter
    def files(self, files):
        """
        Sets the files of this InstancePatch.
        JSON-formatted string containing a dictionary mapping each file declared in the process definition to a URL

        :param files: The files of this InstancePatch.
        :type: str
        """

        self._files = files

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
